#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class TaskStatus:
    def __init__(self):
        self.steps = None
        self.progress = None
        self.lastLogEntry = None
        self.state = None
        self.result = None
        pass


class __TaskStatusSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = TaskStatus()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        stepsValue = value['steps']
        instance.steps = serder.DOUBLE.parse(stepsValue)
        progressValue = value['progress']
        instance.progress = serder.DOUBLE.parse(progressValue)
        lastLogEntryValue = value['lastLogEntry']
        instance.lastLogEntry = serder.STRING.parse(lastLogEntryValue)
        from netbluemind.core.task.api.TaskStatusState import TaskStatusState
        from netbluemind.core.task.api.TaskStatusState import __TaskStatusStateSerDer__
        stateValue = value['state']
        instance.state = __TaskStatusStateSerDer__().parse(stateValue)
        resultValue = value['result']
        instance.result = serder.STRING.parse(resultValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        stepsValue = value.steps
        instance["steps"] = serder.DOUBLE.encode(stepsValue)
        progressValue = value.progress
        instance["progress"] = serder.DOUBLE.encode(progressValue)
        lastLogEntryValue = value.lastLogEntry
        instance["lastLogEntry"] = serder.STRING.encode(lastLogEntryValue)
        from netbluemind.core.task.api.TaskStatusState import TaskStatusState
        from netbluemind.core.task.api.TaskStatusState import __TaskStatusStateSerDer__
        stateValue = value.state
        instance["state"] = __TaskStatusStateSerDer__().encode(stateValue)
        resultValue = value.result
        instance["result"] = serder.STRING.encode(resultValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class GenerationContent:
    def __init__(self):
        self.generationId = None
        self.domains = None
        self.entries = None
        self.capabilities = None
        pass


class __GenerationContentSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = GenerationContent()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        generationIdValue = value['generationId']
        instance.generationId = serder.INT.parse(generationIdValue)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        domainsValue = value['domains']
        instance.domains = serder.ListSerDer(
            __ItemValueSerDer__(__DomainSerDer__())).parse(domainsValue)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        entriesValue = value['entries']
        instance.entries = serder.ListSerDer(
            __ItemValueSerDer__(__DirEntrySerDer__())).parse(entriesValue)
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        capabilitiesValue = value['capabilities']
        instance.capabilities = serder.ListSerDer(
            __RestoreOperationSerDer__()).parse(capabilitiesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        generationIdValue = value.generationId
        instance["generationId"] = serder.INT.encode(generationIdValue)
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        domainsValue = value.domains
        instance["domains"] = serder.ListSerDer(
            __ItemValueSerDer__(__DomainSerDer__())).encode(domainsValue)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        entriesValue = value.entries
        instance["entries"] = serder.ListSerDer(
            __ItemValueSerDer__(__DirEntrySerDer__())).encode(entriesValue)
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        capabilitiesValue = value.capabilities
        instance["capabilities"] = serder.ListSerDer(
            __RestoreOperationSerDer__()).encode(capabilitiesValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxFoldersByContainer_VERSION = "4.1.65246"


class IMailboxFoldersByContainer(BaseEndpoint):
    def __init__(self, apiKey, url, container):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/mail_folders_container/{container}'
        self.container_ = container
        self.base = self.base.replace('{container}', container)

    def getVersion(self):
        postUri = "/_version"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(serder.LONG, response)

    def filteredChangesetById(self, since, arg1):
        postUri = "/_filteredChangesetById"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        __data__ = __ItemFlagFilterSerDer__().encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {'since': since}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemVersion import ItemVersion
        from netbluemind.core.container.model.ItemVersion import __ItemVersionSerDer__
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(__ItemVersionSerDer__()), response)

    def itemChangelog(self, uid, arg1):
        postUri = "/{uid}/_itemchangelog"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.LONG.encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemChangelog import ItemChangelog
        from netbluemind.core.container.model.ItemChangelog import __ItemChangelogSerDer__
        return self.handleResult__(__ItemChangelogSerDer__(), response)

    def changeset(self, since):
        postUri = "/_changeset"
        __data__ = None
        __encoded__ = None
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)

    def changesetById(self, since):
        postUri = "/_changesetById"
        __data__ = None
        __encoded__ = None
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)

    def containerChangelog(self, arg0):
        postUri = "/_changelog"
        __data__ = None
        __encoded__ = None
        __data__ = serder.LONG.encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
        return self.handleResult__(__ContainerChangelogSerDer__(), response)

    def allIds(self, filter, knownContainerVersion, limit, offset):
        postUri = "/_itemIds"
        __data__ = None
        __encoded__ = None
        queryParams = {'filter': filter, 'knownContainerVersion':
                       knownContainerVersion, 'limit': limit, 'offset': offset}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(serder.LONG), response)

    def all(self):
        postUri = "/_all"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)

    def byName(self, name):
        postUri = "/byName/{name}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{name}", name)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)

    def root(self):
        postUri = "/_root"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)

    def searchItems(self, query):
        postUri = "/_search"
        __data__ = None
        __encoded__ = None
        from netbluemind.backend.mail.api.MailboxFolderSearchQuery import MailboxFolderSearchQuery
        from netbluemind.backend.mail.api.MailboxFolderSearchQuery import __MailboxFolderSearchQuerySerDer__
        __data__ = __MailboxFolderSearchQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.SearchResult import SearchResult
        from netbluemind.backend.mail.api.SearchResult import __SearchResultSerDer__
        return self.handleResult__(__SearchResultSerDer__(), response)

    def multipleGetById(self, arg0):
        postUri = "/_mgetById"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.LONG).encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__MailboxFolderSerDer__())), response)

    def getCompleteById(self, id):
        postUri = "/{id}/completeById"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__MailboxFolderSerDer__()), response)

    def importItems(self, folderDestinationId, mailboxItems):
        postUri = "/importItems/{folderDestinationId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{folderDestinationId}", folderDestinationId)
        from netbluemind.backend.mail.api.ImportMailboxItemSet import ImportMailboxItemSet
        from netbluemind.backend.mail.api.ImportMailboxItemSet import __ImportMailboxItemSetSerDer__
        __data__ = __ImportMailboxItemSetSerDer__().encode(mailboxItems)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import ImportMailboxItemsStatus
        from netbluemind.backend.mail.api.ImportMailboxItemsStatus import __ImportMailboxItemsStatusSerDer__
        return self.handleResult__(__ImportMailboxItemsStatusSerDer__(), response)

    def emptyFolder(self, id):
        postUri = "/empty/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def removeMessages(self, id):
        postUri = "/removeMessages/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def markFolderAsRead(self, id):
        postUri = "/markAsRead/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def createBasic(self, value):
        postUri = ""
        __data__ = None
        __encoded__ = None
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        __data__ = __MailboxFolderSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
        return self.handleResult__(__ItemIdentifierSerDer__(), response)

    def createForHierarchy(self, hierarchyId, value):
        postUri = "/id/{hierarchyId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{hierarchyId}", hierarchyId)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        __data__ = __MailboxFolderSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemIdentifier import ItemIdentifier
        from netbluemind.core.container.model.ItemIdentifier import __ItemIdentifierSerDer__
        return self.handleResult__(__ItemIdentifierSerDer__(), response)

    def updateById(self, id, value):
        postUri = "/id/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        from netbluemind.backend.mail.api.MailboxFolder import MailboxFolder
        from netbluemind.backend.mail.api.MailboxFolder import __MailboxFolderSerDer__
        __data__ = __MailboxFolderSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        from netbluemind.core.container.api.Ack import Ack
        from netbluemind.core.container.api.Ack import __AckSerDer__
        return self.handleResult__(__AckSerDer__(), response)

    def deleteById(self, id):
        postUri = "/id/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def deepDelete(self, id):
        postUri = "/deep/{id}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{id}", id)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxFoldersByContainer_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Email:
    def __init__(self):
        self.address = None
        self.allAliases = None
        self.isDefault = None
        pass


class __EmailSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Email()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        addressValue = value['address']
        instance.address = serder.STRING.parse(addressValue)
        allAliasesValue = value['allAliases']
        instance.allAliases = serder.BOOLEAN.parse(allAliasesValue)
        isDefaultValue = value['isDefault']
        instance.isDefault = serder.BOOLEAN.parse(isDefaultValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        addressValue = value.address
        instance["address"] = serder.STRING.encode(addressValue)
        allAliasesValue = value.allAliases
        instance["allAliases"] = serder.BOOLEAN.encode(allAliasesValue)
        isDefaultValue = value.isDefault
        instance["isDefault"] = serder.BOOLEAN.encode(isDefaultValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ContainerQuery:
    def __init__(self):
        self.type = None
        self.name = None
        self.verb = None
        self.owner = None
        self.readonly = None
        self.size = None
        pass


class __ContainerQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ContainerQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        typeValue = value['type']
        instance.type = serder.STRING.parse(typeValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        from netbluemind.core.container.model.acl.Verb import Verb
        from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
        verbValue = value['verb']
        instance.verb = serder.ListSerDer(__VerbSerDer__()).parse(verbValue)
        ownerValue = value['owner']
        instance.owner = serder.STRING.parse(ownerValue)
        readonlyValue = value['readonly']
        instance.readonly = serder.BOOLEAN.parse(readonlyValue)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        typeValue = value.type
        instance["type"] = serder.STRING.encode(typeValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        from netbluemind.core.container.model.acl.Verb import Verb
        from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
        verbValue = value.verb
        instance["verb"] = serder.ListSerDer(
            __VerbSerDer__()).encode(verbValue)
        ownerValue = value.owner
        instance["owner"] = serder.STRING.encode(ownerValue)
        readonlyValue = value.readonly
        instance["readonly"] = serder.BOOLEAN.encode(readonlyValue)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MessageBodyPart:
    def __init__(self):
        self.mime = None
        self.address = None
        self.encoding = None
        self.charset = None
        self.fileName = None
        self.headers = None
        self.contentId = None
        self.children = None
        self.size = None
        self.dispositionType = None
        pass


class __MessageBodyPartSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MessageBodyPart()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mimeValue = value['mime']
        instance.mime = serder.STRING.parse(mimeValue)
        addressValue = value['address']
        instance.address = serder.STRING.parse(addressValue)
        encodingValue = value['encoding']
        instance.encoding = serder.STRING.parse(encodingValue)
        charsetValue = value['charset']
        instance.charset = serder.STRING.parse(charsetValue)
        fileNameValue = value['fileName']
        instance.fileName = serder.STRING.parse(fileNameValue)
        from netbluemind.backend.mail.api.MessageBodyHeader import MessageBodyHeader
        from netbluemind.backend.mail.api.MessageBodyHeader import __MessageBodyHeaderSerDer__
        headersValue = value['headers']
        instance.headers = serder.ListSerDer(
            __MessageBodyHeaderSerDer__()).parse(headersValue)
        contentIdValue = value['contentId']
        instance.contentId = serder.STRING.parse(contentIdValue)
        from netbluemind.backend.mail.api.MessageBodyPart import MessageBodyPart
        from netbluemind.backend.mail.api.MessageBodyPart import __MessageBodyPartSerDer__
        childrenValue = value['children']
        instance.children = serder.ListSerDer(
            __MessageBodyPartSerDer__()).parse(childrenValue)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        from netbluemind.backend.mail.api.DispositionType import DispositionType
        from netbluemind.backend.mail.api.DispositionType import __DispositionTypeSerDer__
        dispositionTypeValue = value['dispositionType']
        instance.dispositionType = __DispositionTypeSerDer__().parse(dispositionTypeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        mimeValue = value.mime
        instance["mime"] = serder.STRING.encode(mimeValue)
        addressValue = value.address
        instance["address"] = serder.STRING.encode(addressValue)
        encodingValue = value.encoding
        instance["encoding"] = serder.STRING.encode(encodingValue)
        charsetValue = value.charset
        instance["charset"] = serder.STRING.encode(charsetValue)
        fileNameValue = value.fileName
        instance["fileName"] = serder.STRING.encode(fileNameValue)
        from netbluemind.backend.mail.api.MessageBodyHeader import MessageBodyHeader
        from netbluemind.backend.mail.api.MessageBodyHeader import __MessageBodyHeaderSerDer__
        headersValue = value.headers
        instance["headers"] = serder.ListSerDer(
            __MessageBodyHeaderSerDer__()).encode(headersValue)
        contentIdValue = value.contentId
        instance["contentId"] = serder.STRING.encode(contentIdValue)
        from netbluemind.backend.mail.api.MessageBodyPart import MessageBodyPart
        from netbluemind.backend.mail.api.MessageBodyPart import __MessageBodyPartSerDer__
        childrenValue = value.children
        instance["children"] = serder.ListSerDer(
            __MessageBodyPartSerDer__()).encode(childrenValue)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        from netbluemind.backend.mail.api.DispositionType import DispositionType
        from netbluemind.backend.mail.api.DispositionType import __DispositionTypeSerDer__
        dispositionTypeValue = value.dispositionType
        instance["dispositionType"] = __DispositionTypeSerDer__().encode(
            dispositionTypeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Message:
    def __init__(self):
        self.sendingAs = None
        self.to = None
        self.cc = None
        self.recipients = None
        self.subject = None
        pass


class __MessageSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Message()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailflow.common.api.SendingAs import SendingAs
        from netbluemind.mailflow.common.api.SendingAs import __SendingAsSerDer__
        sendingAsValue = value['sendingAs']
        instance.sendingAs = __SendingAsSerDer__().parse(sendingAsValue)
        toValue = value['to']
        instance.to = serder.ListSerDer(serder.STRING).parse(toValue)
        ccValue = value['cc']
        instance.cc = serder.ListSerDer(serder.STRING).parse(ccValue)
        recipientsValue = value['recipients']
        instance.recipients = serder.ListSerDer(
            serder.STRING).parse(recipientsValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailflow.common.api.SendingAs import SendingAs
        from netbluemind.mailflow.common.api.SendingAs import __SendingAsSerDer__
        sendingAsValue = value.sendingAs
        instance["sendingAs"] = __SendingAsSerDer__().encode(sendingAsValue)
        toValue = value.to
        instance["to"] = serder.ListSerDer(serder.STRING).encode(toValue)
        ccValue = value.cc
        instance["cc"] = serder.ListSerDer(serder.STRING).encode(ccValue)
        recipientsValue = value.recipients
        instance["recipients"] = serder.ListSerDer(
            serder.STRING).encode(recipientsValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VFreebusyQuery:
    def __init__(self):
        self.dtstart = None
        self.dtend = None
        self.excludedEvents = None
        self.withOOFSlots = None
        pass


class __VFreebusyQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VFreebusyQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtstartValue = value['dtstart']
        instance.dtstart = __BmDateTimeSerDer__().parse(dtstartValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtendValue = value['dtend']
        instance.dtend = __BmDateTimeSerDer__().parse(dtendValue)
        excludedEventsValue = value['excludedEvents']
        instance.excludedEvents = serder.ListSerDer(
            serder.STRING).parse(excludedEventsValue)
        withOOFSlotsValue = value['withOOFSlots']
        instance.withOOFSlots = serder.BOOLEAN.parse(withOOFSlotsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtstartValue = value.dtstart
        instance["dtstart"] = __BmDateTimeSerDer__().encode(dtstartValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtendValue = value.dtend
        instance["dtend"] = __BmDateTimeSerDer__().encode(dtendValue)
        excludedEventsValue = value.excludedEvents
        instance["excludedEvents"] = serder.ListSerDer(
            serder.STRING).encode(excludedEventsValue)
        withOOFSlotsValue = value.withOOFSlots
        instance["withOOFSlots"] = serder.BOOLEAN.encode(withOOFSlotsValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VNoteQuery:
    def __init__(self):
        self.from_ = None
        self.size = None
        self.query = None
        self.escapeQuery = None
        pass


class __VNoteQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VNoteQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from_Value = value['from']
        instance.from_ = serder.INT.parse(from_Value)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        queryValue = value['query']
        instance.query = serder.STRING.parse(queryValue)
        escapeQueryValue = value['escapeQuery']
        instance.escapeQuery = serder.BOOLEAN.parse(escapeQueryValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from_Value = value.from_
        instance["from"] = serder.INT.encode(from_Value)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        queryValue = value.query
        instance["query"] = serder.STRING.encode(queryValue)
        escapeQueryValue = value.escapeQuery
        instance["escapeQuery"] = serder.BOOLEAN.encode(escapeQueryValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IContainerManagement_VERSION = "4.1.65246"


class IContainerManagement(BaseEndpoint):
    def __init__(self, apiKey, url, containerUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/containers/_manage/{containerUid}'
        self.containerUid_ = containerUid
        self.base = self.base.replace('{containerUid}', containerUid)

    def getDescriptor(self):
        postUri = "/_descriptor"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(__ContainerDescriptorSerDer__(), response)

    def getSettings(self):
        postUri = "/_settings"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(serder.MapSerDer(serder.STRING), response)

    def getAccessControlList(self):
        postUri = "/_acl"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        return self.handleResult__(serder.ListSerDer(__AccessControlEntrySerDer__()), response)

    def getAllItems(self):
        postUri = "/_list"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)

    def subscribers(self):
        postUri = "/_subscription"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def getItemCount(self):
        postUri = "/_itemCount"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.api.Count import Count
        from netbluemind.core.container.api.Count import __CountSerDer__
        return self.handleResult__(__CountSerDer__(), response)

    def setAccessControlList(self, entries):
        postUri = "/_acl"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        __data__ = serder.ListSerDer(
            __AccessControlEntrySerDer__()).encode(entries)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, descriptor):
        postUri = "/_descriptor"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
        from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
        __data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def allowOfflineSync(self, subject):
        postUri = "/{subject}/offlineSync"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}", subject)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setSettings(self, settings):
        postUri = "/_settings"
        __data__ = None
        __encoded__ = None
        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getItems(self, uids):
        postUri = "/_mget"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)

    def disallowOfflineSync(self, subject):
        postUri = "/{subject}/offlineSync"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}", subject)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def canAccess(self, verbsOrRoles):
        postUri = "/_canAccess"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(verbsOrRoles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def setPersonalSettings(self, settings):
        postUri = "/_personalSettings"
        __data__ = None
        __encoded__ = None
        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getFilteredItems(self, filter):
        postUri = "/_filtered"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        __data__ = __ItemFlagFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainerManagement_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ContainerUpdatesResult:
    def __init__(self):
        self.added = None
        self.updated = None
        self.removed = None
        self.unhandled = None
        self.errors = None
        self.version = None
        pass


class __ContainerUpdatesResultSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ContainerUpdatesResult()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        addedValue = value['added']
        instance.added = serder.ListSerDer(serder.STRING).parse(addedValue)
        updatedValue = value['updated']
        instance.updated = serder.ListSerDer(serder.STRING).parse(updatedValue)
        removedValue = value['removed']
        instance.removed = serder.ListSerDer(serder.STRING).parse(removedValue)
        unhandledValue = value['unhandled']
        instance.unhandled = serder.ListSerDer(
            serder.STRING).parse(unhandledValue)
        from netbluemind.core.container.model.ContainerUpdatesResultInError import ContainerUpdatesResultInError
        from netbluemind.core.container.model.ContainerUpdatesResultInError import __ContainerUpdatesResultInErrorSerDer__
        errorsValue = value['errors']
        instance.errors = serder.ListSerDer(
            __ContainerUpdatesResultInErrorSerDer__()).parse(errorsValue)
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        addedValue = value.added
        instance["added"] = serder.ListSerDer(serder.STRING).encode(addedValue)
        updatedValue = value.updated
        instance["updated"] = serder.ListSerDer(
            serder.STRING).encode(updatedValue)
        removedValue = value.removed
        instance["removed"] = serder.ListSerDer(
            serder.STRING).encode(removedValue)
        unhandledValue = value.unhandled
        instance["unhandled"] = serder.ListSerDer(
            serder.STRING).encode(unhandledValue)
        from netbluemind.core.container.model.ContainerUpdatesResultInError import ContainerUpdatesResultInError
        from netbluemind.core.container.model.ContainerUpdatesResultInError import __ContainerUpdatesResultInErrorSerDer__
        errorsValue = value.errors
        instance["errors"] = serder.ListSerDer(
            __ContainerUpdatesResultInErrorSerDer__()).encode(errorsValue)
        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IContainers_VERSION = "4.1.65246"


class IContainers(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/containers/_manage'

    def all(self, query):
        postUri = "/_list"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
        __data__ = __ContainerQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)

    def getContainers(self, containerIds):
        postUri = "/_mget"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(containerIds)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)

    def setAccessControlList(self, uid, entries):
        postUri = "/{uid}/_acl"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        __data__ = serder.ListSerDer(
            __AccessControlEntrySerDer__()).encode(entries)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, uid, descriptor):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
        from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
        __data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def allLight(self, query):
        postUri = "/_listLight"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
        __data__ = __ContainerQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)

    def allForUser(self, domainUid, userUid, query):
        postUri = "/_listforuser"
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.api.ContainerQuery import ContainerQuery
        from netbluemind.core.container.api.ContainerQuery import __ContainerQuerySerDer__
        __data__ = __ContainerQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {'domainUid': domainUid, 'userUid': userUid}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ContainerDescriptorSerDer__()), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getContainersLight(self, containerIds):
        postUri = "/_mgetLight"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(containerIds)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
        from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__BaseContainerDescriptorSerDer__()), response)

    def get(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(__ContainerDescriptorSerDer__(), response)

    def create(self, uid, descriptor):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        __data__ = __ContainerDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getIfPresent(self, uid):
        postUri = "/_ifPresent/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(__ContainerDescriptorSerDer__(), response)

    def getForUser(self, domainUid, userUid, uid):
        postUri = "/_forUser"
        __data__ = None
        __encoded__ = None
        queryParams = {'domainUid': domainUid, 'userUid': userUid, 'uid': uid}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IContainers_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(__ContainerDescriptorSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IAddressBooksMgmt_VERSION = "4.1.65246"


class IAddressBooksMgmt(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/mgmt/addressbooks'

    def backup(self, containerUid, since):
        postUri = "/{containerUid}/_backupstream"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        return response.content

    def reindexDomain(self, domain):
        postUri = "/_reindexDomain"
        __data__ = None
        __encoded__ = None
        queryParams = {'domain': domain}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def reindex(self, containerUid):
        postUri = "/{containerUid}/_reindex"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def restore(self, containerUid, restoreStream, reset):
        postUri = "/{containerUid}/_restorestream"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        __data__ = serder.STREAM.encode(restoreStream)
        __encoded__ = __data__
        queryParams = {'reset': reset}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def update(self, containerUid, descriptor):
        postUri = "/{containerUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
        from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
        __data__ = __AddressBookDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def reindexAll(self):
        postUri = "/_reindex"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def delete(self, containerUid):
        postUri = "/{containerUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getComplete(self, containerUid):
        postUri = "/{containerUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
        from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
        return self.handleResult__(__AddressBookDescriptorSerDer__(), response)

    def create(self, containerUid, descriptor, isDefault):
        postUri = "/{containerUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{containerUid}", containerUid)
        from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
        from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
        __data__ = __AddressBookDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {'isDefault': isDefault}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAddressBooksMgmt_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ICalendarAutocomplete_VERSION = "4.1.65246"


class ICalendarAutocomplete(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/calendar/autocomplete'

    def calendarLookup(self, pattern, verb):
        postUri = "/_calendarLookup/{pattern}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{pattern}", pattern)
        from netbluemind.core.container.model.acl.Verb import Verb
        from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
        __data__ = __VerbSerDer__().encode(verb)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ICalendarAutocomplete_VERSION}, data=__encoded__)
        from netbluemind.calendar.api.CalendarLookupResponse import CalendarLookupResponse
        from netbluemind.calendar.api.CalendarLookupResponse import __CalendarLookupResponseSerDer__
        return self.handleResult__(serder.ListSerDer(__CalendarLookupResponseSerDer__()), response)

    def calendarGroupLookup(self, groupUid):
        postUri = "/_calendarsGroupLookup/{groupUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{groupUid}", groupUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ICalendarAutocomplete_VERSION}, data=__encoded__)
        from netbluemind.calendar.api.CalendarLookupResponse import CalendarLookupResponse
        from netbluemind.calendar.api.CalendarLookupResponse import __CalendarLookupResponseSerDer__
        return self.handleResult__(serder.ListSerDer(__CalendarLookupResponseSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VEventSeries:
    def __init__(self):
        self.main = None
        self.occurrences = None
        self.counters = None
        self.properties = None
        self.icsUid = None
        self.acceptCounters = None
        pass


class __VEventSeriesSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VEventSeries()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.calendar.api.VEvent import VEvent
        from netbluemind.calendar.api.VEvent import __VEventSerDer__
        mainValue = value['main']
        instance.main = __VEventSerDer__().parse(mainValue)
        from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
        from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
        occurrencesValue = value['occurrences']
        instance.occurrences = serder.ListSerDer(
            __VEventOccurrenceSerDer__()).parse(occurrencesValue)
        from netbluemind.calendar.api.VEventCounter import VEventCounter
        from netbluemind.calendar.api.VEventCounter import __VEventCounterSerDer__
        countersValue = value['counters']
        instance.counters = serder.ListSerDer(
            __VEventCounterSerDer__()).parse(countersValue)
        propertiesValue = value['properties']
        instance.properties = serder.MapSerDer(
            serder.STRING).parse(propertiesValue)
        icsUidValue = value['icsUid']
        instance.icsUid = serder.STRING.parse(icsUidValue)
        acceptCountersValue = value['acceptCounters']
        instance.acceptCounters = serder.BOOLEAN.parse(acceptCountersValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.calendar.api.VEvent import VEvent
        from netbluemind.calendar.api.VEvent import __VEventSerDer__
        mainValue = value.main
        instance["main"] = __VEventSerDer__().encode(mainValue)
        from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
        from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
        occurrencesValue = value.occurrences
        instance["occurrences"] = serder.ListSerDer(
            __VEventOccurrenceSerDer__()).encode(occurrencesValue)
        from netbluemind.calendar.api.VEventCounter import VEventCounter
        from netbluemind.calendar.api.VEventCounter import __VEventCounterSerDer__
        countersValue = value.counters
        instance["counters"] = serder.ListSerDer(
            __VEventCounterSerDer__()).encode(countersValue)
        propertiesValue = value.properties
        instance["properties"] = serder.MapSerDer(
            serder.STRING).encode(propertiesValue)
        icsUidValue = value.icsUid
        instance["icsUid"] = serder.STRING.encode(icsUidValue)
        acceptCountersValue = value.acceptCounters
        instance["acceptCounters"] = serder.BOOLEAN.encode(acceptCountersValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IComputerTelephonyIntegration_VERSION = "4.1.65246"


class IComputerTelephonyIntegration(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid, userUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/cti/{domainUid}/{userUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)
        self.userUid_ = userUid
        self.base = self.base.replace('{userUid}', userUid)

    def getUserEmails(self):
        postUri = "/users"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IComputerTelephonyIntegration_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def forward(self, component, phoneNumber):
        postUri = "/forward/{component}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{component}", component)
        queryParams = {'phoneNumber': phoneNumber}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IComputerTelephonyIntegration_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getStatus(self):
        postUri = "/status"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IComputerTelephonyIntegration_VERSION}, data=__encoded__)
        from netbluemind.cti.api.Status import Status
        from netbluemind.cti.api.Status import __StatusSerDer__
        return self.handleResult__(__StatusSerDer__(), response)

    def setStatus(self, component, status):
        postUri = "/status/{component}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{component}", component)
        from netbluemind.cti.api.Status import Status
        from netbluemind.cti.api.Status import __StatusSerDer__
        __data__ = __StatusSerDer__().encode(status)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IComputerTelephonyIntegration_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def dial(self, number):
        postUri = "/dial"
        __data__ = None
        __encoded__ = None
        queryParams = {'number': number}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IComputerTelephonyIntegration_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IAuthentication_VERSION = "4.1.65246"


class IAuthentication(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/auth'

    def getCurrentUser(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.AuthUser import AuthUser
        from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
        return self.handleResult__(__AuthUserSerDer__(), response)

    def su(self, login):
        postUri = "/_su"
        __data__ = None
        __encoded__ = None
        queryParams = {'login': login}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)

    def ping(self):
        postUri = "/ping"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def login(self, login, password, origin):
        postUri = "/login"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {'login': login, 'origin': origin}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)

    def loginWithParams(self, login, password, origin, interactive):
        postUri = "/loginWithParams"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {'login': login, 'origin': origin,
                       'interactive': interactive}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)

    def logout(self):
        postUri = "/logout"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def suWithParams(self, login, interactive):
        postUri = "/_suWithParams"
        __data__ = None
        __encoded__ = None
        queryParams = {'login': login, 'interactive': interactive}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.LoginResponse import LoginResponse
        from netbluemind.authentication.api.LoginResponse import __LoginResponseSerDer__
        return self.handleResult__(__LoginResponseSerDer__(), response)

    def validate(self, login, password, origin):
        postUri = "/validate"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {'login': login, 'origin': origin}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IAuthentication_VERSION}, data=__encoded__)
        from netbluemind.authentication.api.ValidationKind import ValidationKind
        from netbluemind.authentication.api.ValidationKind import __ValidationKindSerDer__
        return self.handleResult__(__ValidationKindSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class CloneConfiguration:
    def __init__(self):
        self.sourceInstallationId = None
        self.targetInstallationId = None
        self.uidToIpMapping = None
        self.sysconfOverride = None
        self.mode = None
        self.cloneWorkers = None
        self.skippedContainerTypes = None
        pass


class __CloneConfigurationSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = CloneConfiguration()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        sourceInstallationIdValue = value['sourceInstallationId']
        instance.sourceInstallationId = serder.STRING.parse(
            sourceInstallationIdValue)
        targetInstallationIdValue = value['targetInstallationId']
        instance.targetInstallationId = serder.STRING.parse(
            targetInstallationIdValue)
        uidToIpMappingValue = value['uidToIpMapping']
        instance.uidToIpMapping = serder.MapSerDer(
            serder.STRING).parse(uidToIpMappingValue)
        sysconfOverrideValue = value['sysconfOverride']
        instance.sysconfOverride = serder.MapSerDer(
            serder.STRING).parse(sysconfOverrideValue)
        from netbluemind.system.api.CloneConfigurationMode import CloneConfigurationMode
        from netbluemind.system.api.CloneConfigurationMode import __CloneConfigurationModeSerDer__
        modeValue = value['mode']
        instance.mode = __CloneConfigurationModeSerDer__().parse(modeValue)
        cloneWorkersValue = value['cloneWorkers']
        instance.cloneWorkers = serder.INT.parse(cloneWorkersValue)
        skippedContainerTypesValue = value['skippedContainerTypes']
        instance.skippedContainerTypes = serder.SetSerDer(
            serder.STRING).parse(skippedContainerTypesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        sourceInstallationIdValue = value.sourceInstallationId
        instance["sourceInstallationId"] = serder.STRING.encode(
            sourceInstallationIdValue)
        targetInstallationIdValue = value.targetInstallationId
        instance["targetInstallationId"] = serder.STRING.encode(
            targetInstallationIdValue)
        uidToIpMappingValue = value.uidToIpMapping
        instance["uidToIpMapping"] = serder.MapSerDer(
            serder.STRING).encode(uidToIpMappingValue)
        sysconfOverrideValue = value.sysconfOverride
        instance["sysconfOverride"] = serder.MapSerDer(
            serder.STRING).encode(sysconfOverrideValue)
        from netbluemind.system.api.CloneConfigurationMode import CloneConfigurationMode
        from netbluemind.system.api.CloneConfigurationMode import __CloneConfigurationModeSerDer__
        modeValue = value.mode
        instance["mode"] = __CloneConfigurationModeSerDer__().encode(modeValue)
        cloneWorkersValue = value.cloneWorkers
        instance["cloneWorkers"] = serder.INT.encode(cloneWorkersValue)
        skippedContainerTypesValue = value.skippedContainerTypes
        instance["skippedContainerTypes"] = serder.SetSerDer(
            serder.STRING).encode(skippedContainerTypesValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class IdQuery:
    def __init__(self):
        self.filter = None
        self.limit = None
        self.offset = None
        self.knownContainerVersion = None
        pass


class __IdQuerySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = IdQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        filterValue = value['filter']
        instance.filter = __ItemFlagFilterSerDer__().parse(filterValue)
        limitValue = value['limit']
        instance.limit = serder.INT.parse(limitValue)
        offsetValue = value['offset']
        instance.offset = serder.INT.parse(offsetValue)
        knownContainerVersionValue = value['knownContainerVersion']
        instance.knownContainerVersion = serder.LONG.parse(
            knownContainerVersionValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        filterValue = value.filter
        instance["filter"] = __ItemFlagFilterSerDer__().encode(filterValue)
        limitValue = value.limit
        instance["limit"] = serder.INT.encode(limitValue)
        offsetValue = value.offset
        instance["offset"] = serder.INT.encode(offsetValue)
        knownContainerVersionValue = value.knownContainerVersion
        instance["knownContainerVersion"] = serder.LONG.encode(
            knownContainerVersionValue)
        return instance



import base64
from base64 import b64decode
from base64 import b64encode
from datetime import datetime


class ByteArraySerDer:

    @classmethod
    def parse(cls, value):
        if value == None:
            return None
        else:
            return b64decode(value)

    @classmethod
    def encode(cls, value):
        if value == None:
            return None
        else:
            return b64encode(value).decode()


class STRING:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class STREAM:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class LONG:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class DOUBLE:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class INT:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class DATE:

    @classmethod
    def parse(cls, value):
        if value == None:
            return None
        else:
            return datetime.fromtimestamp(value/1000)

    @classmethod
    def encode(cls, value):
        if value == None:
            return None
        else:
            return int((value - datetime(1970, 1, 1)).total_seconds() * 1000)


class BOOLEAN:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class VOID:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class MapSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = dict()
        for v in value.keys():
            ret[v] = self.serder.parse(value[v])
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = dict()
        for v in value.keys():
            ret[v] = self.serder.encode(value[v])
        return ret


class CollectionSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.parse(v))
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.encode(v))
        return ret


class ListSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.parse(v))
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.encode(v))
        return ret


class ArraySerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.parse(v))
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.encode(v))
        return ret


class SetSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.parse(v))
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append(self.serder.encode(v))
        return ret



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class LogEntry:
    def __init__(self):
        self.timestamp = None
        self.severity = None
        self.locale = None
        self.content = None
        self.offset = None
        pass


class __LogEntrySerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = LogEntry()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        timestampValue = value['timestamp']
        instance.timestamp = serder.LONG.parse(timestampValue)
        from netbluemind.scheduledjob.api.LogLevel import LogLevel
        from netbluemind.scheduledjob.api.LogLevel import __LogLevelSerDer__
        severityValue = value['severity']
        instance.severity = __LogLevelSerDer__().parse(severityValue)
        localeValue = value['locale']
        instance.locale = serder.STRING.parse(localeValue)
        contentValue = value['content']
        instance.content = serder.STRING.parse(contentValue)
        offsetValue = value['offset']
        instance.offset = serder.INT.parse(offsetValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        timestampValue = value.timestamp
        instance["timestamp"] = serder.LONG.encode(timestampValue)
        from netbluemind.scheduledjob.api.LogLevel import LogLevel
        from netbluemind.scheduledjob.api.LogLevel import __LogLevelSerDer__
        severityValue = value.severity
        instance["severity"] = __LogLevelSerDer__().encode(severityValue)
        localeValue = value.locale
        instance["locale"] = serder.STRING.encode(localeValue)
        contentValue = value.content
        instance["content"] = serder.STRING.encode(contentValue)
        offsetValue = value.offset
        instance["offset"] = serder.INT.encode(offsetValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class HotUpgradeTask:
    def __init__(self):
        self.id = None
        self.operation = None
        self.parameters = None
        self.status = None
        self.failure = None
        self.createdAt = None
        self.updatedAt = None
        self.executionMode = None
        self.retryCount = None
        self.retryDelaySeconds = None
        self.reportFailure = None
        pass


class __HotUpgradeTaskSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = HotUpgradeTask()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.INT.parse(idValue)
        operationValue = value['operation']
        instance.operation = serder.STRING.parse(operationValue)
        parametersValue = value['parameters']
        instance.parameters = serder.STRING.parse(parametersValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import HotUpgradeTaskStatus
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import __HotUpgradeTaskStatusSerDer__
        statusValue = value['status']
        instance.status = __HotUpgradeTaskStatusSerDer__().parse(statusValue)
        failureValue = value['failure']
        instance.failure = serder.INT.parse(failureValue)
        createdAtValue = value['createdAt']
        instance.createdAt = serder.DATE.parse(createdAtValue)
        updatedAtValue = value['updatedAt']
        instance.updatedAt = serder.DATE.parse(updatedAtValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
        executionModeValue = value['executionMode']
        instance.executionMode = __HotUpgradeTaskExecutionModeSerDer__().parse(executionModeValue)
        retryCountValue = value['retryCount']
        instance.retryCount = serder.INT.parse(retryCountValue)
        retryDelaySecondsValue = value['retryDelaySeconds']
        instance.retryDelaySeconds = serder.INT.parse(retryDelaySecondsValue)
        reportFailureValue = value['reportFailure']
        instance.reportFailure = serder.BOOLEAN.parse(reportFailureValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.INT.encode(idValue)
        operationValue = value.operation
        instance["operation"] = serder.STRING.encode(operationValue)
        parametersValue = value.parameters
        instance["parameters"] = serder.STRING.encode(parametersValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import HotUpgradeTaskStatus
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import __HotUpgradeTaskStatusSerDer__
        statusValue = value.status
        instance["status"] = __HotUpgradeTaskStatusSerDer__().encode(statusValue)
        failureValue = value.failure
        instance["failure"] = serder.INT.encode(failureValue)
        createdAtValue = value.createdAt
        instance["createdAt"] = serder.DATE.encode(createdAtValue)
        updatedAtValue = value.updatedAt
        instance["updatedAt"] = serder.DATE.encode(updatedAtValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
        executionModeValue = value.executionMode
        instance["executionMode"] = __HotUpgradeTaskExecutionModeSerDer__().encode(
            executionModeValue)
        retryCountValue = value.retryCount
        instance["retryCount"] = serder.INT.encode(retryCountValue)
        retryDelaySecondsValue = value.retryDelaySeconds
        instance["retryDelaySeconds"] = serder.INT.encode(
            retryDelaySecondsValue)
        reportFailureValue = value.reportFailure
        instance["reportFailure"] = serder.BOOLEAN.encode(reportFailureValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IUser_VERSION = "4.1.65246"


class IUser(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/users/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def getPhoto(self, uid):
        postUri = "/{uid}/photo"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def deletePhoto(self, uid):
        postUri = "/{uid}/photo"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getIcon(self, uid):
        postUri = "/{uid}/icon"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def setPhoto(self, uid, arg1):
        postUri = "/{uid}/photo"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.ByteArraySerDer.encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setExtId(self, uid, arg1):
        postUri = "/{uid}/_extId"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.STRING.encode(arg1)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def memberOf(self, uid):
        postUri = "/{uid}/groups"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)

    def memberOfGroups(self, uid):
        postUri = "/{uid}/groupUids"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def setPassword(self, uid, password):
        postUri = "/{uid}/password_"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.user.api.ChangePassword import ChangePassword
        from netbluemind.user.api.ChangePassword import __ChangePasswordSerDer__
        __data__ = __ChangePasswordSerDer__().encode(password)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def allUids(self):
        postUri = "/_alluids"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def update(self, uid, user):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        __data__ = __UserSerDer__().encode(user)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getVCard(self, uid):
        postUri = "/{uid}/vcard"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        return self.handleResult__(__VCardSerDer__(), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def updateAccountType(self, uid, accountType):
        postUri = "/_updateAccountType/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        __data__ = __BaseDirEntryAccountTypeSerDer__().encode(accountType)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getResolvedRoles(self, uid):
        postUri = "/{uid}/roles_resolved"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def byLogin(self, login):
        postUri = "/byLogin/{login}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{login}", login)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)

    def byEmail(self, email):
        postUri = "/byEmail/{email}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{email}", email)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)

    def create(self, uid, user):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        __data__ = __UserSerDer__().encode(user)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setRoles(self, uid, roles):
        postUri = "/{uid}/roles"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getRoles(self, uid):
        postUri = "/{uid}/roles"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def updateVCard(self, uid, userVCard):
        postUri = "/{uid}/vcard"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        __data__ = __VCardSerDer__().encode(userVCard)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def byExtId(self, extid):
        postUri = "/byExtId/{extid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{extid}", extid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__UserSerDer__()), response)

    def getUsersWithRoles(self, roles):
        postUri = "/_roleusers"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def createWithExtId(self, uid, extid, user):
        postUri = "/{uid}/{extid}/createwithextid"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{extid}", extid)
        from netbluemind.user.api.User import User
        from netbluemind.user.api.User import __UserSerDer__
        __data__ = __UserSerDer__().encode(user)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Device:
    def __init__(self):
        self.identifier = None
        self.owner = None
        self.type = None
        self.wipeDate = None
        self.wipeBy = None
        self.unwipeDate = None
        self.unwipeBy = None
        self.isWipe = None
        self.hasPartnership = None
        self.policy = None
        self.lastSync = None
        pass


class __DeviceSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Device()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        identifierValue = value['identifier']
        instance.identifier = serder.STRING.parse(identifierValue)
        ownerValue = value['owner']
        instance.owner = serder.STRING.parse(ownerValue)
        typeValue = value['type']
        instance.type = serder.STRING.parse(typeValue)
        wipeDateValue = value['wipeDate']
        instance.wipeDate = serder.DATE.parse(wipeDateValue)
        wipeByValue = value['wipeBy']
        instance.wipeBy = serder.STRING.parse(wipeByValue)
        unwipeDateValue = value['unwipeDate']
        instance.unwipeDate = serder.DATE.parse(unwipeDateValue)
        unwipeByValue = value['unwipeBy']
        instance.unwipeBy = serder.STRING.parse(unwipeByValue)
        isWipeValue = value['isWipe']
        instance.isWipe = serder.BOOLEAN.parse(isWipeValue)
        hasPartnershipValue = value['hasPartnership']
        instance.hasPartnership = serder.BOOLEAN.parse(hasPartnershipValue)
        policyValue = value['policy']
        instance.policy = serder.INT.parse(policyValue)
        lastSyncValue = value['lastSync']
        instance.lastSync = serder.DATE.parse(lastSyncValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        identifierValue = value.identifier
        instance["identifier"] = serder.STRING.encode(identifierValue)
        ownerValue = value.owner
        instance["owner"] = serder.STRING.encode(ownerValue)
        typeValue = value.type
        instance["type"] = serder.STRING.encode(typeValue)
        wipeDateValue = value.wipeDate
        instance["wipeDate"] = serder.DATE.encode(wipeDateValue)
        wipeByValue = value.wipeBy
        instance["wipeBy"] = serder.STRING.encode(wipeByValue)
        unwipeDateValue = value.unwipeDate
        instance["unwipeDate"] = serder.DATE.encode(unwipeDateValue)
        unwipeByValue = value.unwipeBy
        instance["unwipeBy"] = serder.STRING.encode(unwipeByValue)
        isWipeValue = value.isWipe
        instance["isWipe"] = serder.BOOLEAN.encode(isWipeValue)
        hasPartnershipValue = value.hasPartnership
        instance["hasPartnership"] = serder.BOOLEAN.encode(hasPartnershipValue)
        policyValue = value.policy
        instance["policy"] = serder.INT.encode(policyValue)
        lastSyncValue = value.lastSync
        instance["lastSync"] = serder.DATE.encode(lastSyncValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class RepairConfig:
    def __init__(self):
        self.opIdentifiers = None
        self.dry = None
        self.logToCoreLog = None
        self.verbose = None
        pass


class __RepairConfigSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = RepairConfig()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        opIdentifiersValue = value['opIdentifiers']
        instance.opIdentifiers = serder.SetSerDer(
            serder.STRING).parse(opIdentifiersValue)
        dryValue = value['dry']
        instance.dry = serder.BOOLEAN.parse(dryValue)
        logToCoreLogValue = value['logToCoreLog']
        instance.logToCoreLog = serder.BOOLEAN.parse(logToCoreLogValue)
        verboseValue = value['verbose']
        instance.verbose = serder.BOOLEAN.parse(verboseValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        opIdentifiersValue = value.opIdentifiers
        instance["opIdentifiers"] = serder.SetSerDer(
            serder.STRING).encode(opIdentifiersValue)
        dryValue = value.dry
        instance["dry"] = serder.BOOLEAN.encode(dryValue)
        logToCoreLogValue = value.logToCoreLog
        instance["logToCoreLog"] = serder.BOOLEAN.encode(logToCoreLogValue)
        verboseValue = value.verbose
        instance["verbose"] = serder.BOOLEAN.encode(verboseValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ITags_VERSION = "4.1.65246"


class ITags(BaseEndpoint):
    def __init__(self, apiKey, url, containerUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/tags/{containerUid}'
        self.containerUid_ = containerUid
        self.base = self.base.replace('{containerUid}', containerUid)

    def all(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.tag.api.Tag import Tag
        from netbluemind.tag.api.Tag import __TagSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)

    def multipleGet(self, uids):
        postUri = "/_mget"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.tag.api.Tag import Tag
        from netbluemind.tag.api.Tag import __TagSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)

    def allUids(self):
        postUri = "/_alluids"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def changelog(self, since):
        postUri = "/_changelog"
        __data__ = None
        __encoded__ = None
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
        return self.handleResult__(__ContainerChangelogSerDer__(), response)

    def update(self, uid, tag):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.tag.api.Tag import Tag
        from netbluemind.tag.api.Tag import __TagSerDer__
        __data__ = __TagSerDer__().encode(tag)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updates(self, changes):
        postUri = "/_mupdates"
        __data__ = None
        __encoded__ = None
        from netbluemind.tag.api.TagChanges import TagChanges
        from netbluemind.tag.api.TagChanges import __TagChangesSerDer__
        __data__ = __TagChangesSerDer__().encode(changes)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
        from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
        return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def changeset(self, since):
        postUri = "/_changeset"
        __data__ = None
        __encoded__ = None
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)

    def getComplete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        from netbluemind.tag.api.Tag import Tag
        from netbluemind.tag.api.Tag import __TagSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__TagSerDer__()), response)

    def create(self, uid, tag):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.tag.api.Tag import Tag
        from netbluemind.tag.api.Tag import __TagSerDer__
        __data__ = __TagSerDer__().encode(tag)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': ITags_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)
